@@ -36,6 +36,11 @@ class UpdateLiveStreamMonitorRequest(RpcRequest):
 
 	def set_MonitorId(self, MonitorId):  # String
 		self.add_query_param('MonitorId', MonitorId)
+	def get_MonitorConfig(self): # String
+		return self.get_query_params().get('MonitorConfig')
+
+	def set_MonitorConfig(self, MonitorConfig):  # String
+		self.add_query_param('MonitorConfig', MonitorConfig)
 	def get_MonitorName(self): # String
 		return self.get_query_params().get('MonitorName')
 
